@@ -266,6 +266,13 @@ def parse_coverage_number(line):
     return line.rpartition('%')[0].rpartition(' ')[-1].rpartition('\t')[-1]
 
 
+def get_echospace():
+    # The margin (12) was determined empirically as the smallest value
+    # that avoids a 'Press enter to continue...' message.
+    # v:echospace exists since vim 8.1.1913 and removes the need to guess.
+    return int(vim.eval('exists("v:echospace") ? v:echospace : &columns - 12'))
+
+
 def parse_coverage_output(output, filename):
     # Example output without branch coverage:
     # Name                          Stmts   Exec  Cover   Missing
@@ -280,7 +287,6 @@ def parse_coverage_output(output, filename):
     if not output:
         print("Got no output!")
         return
-    last_line = output.splitlines()[-1]
     filename = os.path.relpath(filename)
     filename_no_ext = os.path.splitext(filename)[0]
     signs = Signs()
@@ -290,23 +296,24 @@ def parse_coverage_output(output, filename):
         filename_no_ext + ' ',
         './' + filename_no_ext + ' ',
     )
-    if last_line.startswith(expect_one_of):
-        # The margin (15) was determined empirically as the smallest value
-        # that avoids a 'Press enter to continue...' message
-        truncate_to = int(vim.eval('&columns')) - 15
-        if len(last_line) <= truncate_to or get_verbosity() >= 1:
-            print(last_line)
-        else:
-            print(last_line[:truncate_to] + '...')
-        last_line = last_line[len(filename_no_ext) + 1:].lstrip()
-        signs.set_file_coverage(parse_coverage_number(last_line))
-        missing = last_line.rpartition('%')[-1]
-        if missing and missing.strip():
-            signs.clear()
-            parse_lines(missing, signs)
-            signs.save()
+    for line in output.splitlines():
+        if line.startswith(expect_one_of):
+            # Truncate to avoid the 'Press enter to continue...' message
+            truncate_to = get_echospace()
+            if len(line) <= truncate_to or get_verbosity() >= 1:
+                print(line)
+            else:
+                print(line[:truncate_to - 3] + '...')
+            line = line[len(filename_no_ext) + 1:].lstrip()
+            signs.set_file_coverage(parse_coverage_number(line))
+            missing = line.rpartition('%')[-1]
+            if missing and missing.strip():
+                signs.clear()
+                parse_lines(missing, signs)
+                signs.save()
+            break
     else:
-        print("Got confused by %s" % repr(last_line))
+        print("Failed to parse coverage report!")
         print("Expected it to start with %s" % repr(filename_no_ext + ' '))
         print("Full output:")
         print(output)
@@ -415,8 +422,9 @@ def find_coverage_file_for(filename):
 def run_coverage_report(coverage_script, coverage_dir, args=[]):
     print("Running %s report -m %s" % (os.path.relpath(coverage_script), ' '.join(args)))
     if os.path.exists(coverage_script):
-        command = [coverage_script]
+        command = [os.path.abspath(coverage_script)]
     else:
+        # things like "python3 -m coverage"
         command = shlex.split(coverage_script)
     output = subprocess.Popen(command + ['report', '-m'] + args,
                               stdout=subprocess.PIPE,
@@ -461,9 +469,12 @@ def highlight(arg=''):
         if not filename:
             error("Current buffer has no name.")
             return
-        coverage_script = find_coverage_script()
         coverage_dir = find_coverage_file_for(filename)
-        if coverage_script and coverage_dir:
+        if coverage_dir:
+            coverage_script = find_coverage_script()
+            if not coverage_script:
+                error("Could not find the 'coverage' script.")
+                return
             relfilename = os.path.relpath(filename, coverage_dir)
             output = run_coverage_report(coverage_script, coverage_dir, [relfilename])
             parse_coverage_output(output, relfilename)
